package kccf.ton.service.impl;

import java.util.List;

import javax.annotation.Resource;

import kccf.ton.service.LocalToonService;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import cmm.service.CmmActivityHstVO;
import cmm.service.CmmAmsAssetMediaVO;
import cmm.util.DataMap;
import egovframework.rte.fdl.cmmn.EgovAbstractServiceImpl;
import egovframework.rte.fdl.cmmn.exception.EgovBizException;

@Service("localToonService")
public class LocalToonServiceImpl  extends EgovAbstractServiceImpl implements LocalToonService{
	/** LOGGER */
	@SuppressWarnings("unused")
	private static final Logger LOGGER = LoggerFactory.getLogger(LocalToonServiceImpl.class);
	
	/** localToonDAO */
    @Resource(name="localToonDAO")
    private LocalToonDAO localToonDAO;
    
    @Override
    public List<CmmAmsAssetMediaVO> selectLocalToonTopList(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (List<CmmAmsAssetMediaVO>)localToonDAO.selectLocalToonTopList(param);
    }

    @Override
    public int selectLocalToonListTotCnt(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (Integer)localToonDAO.selectLocalToonListTotCnt(param);
    }
    @Override
    public List<CmmAmsAssetMediaVO> selectLocalToonList(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (List<CmmAmsAssetMediaVO>)localToonDAO.selectLocalToonList(param);
    }
    public List<CmmActivityHstVO> selectLocalToonOpenPageList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException{
    	return (List<CmmActivityHstVO>)localToonDAO.selectLocalToonOpenPageList(cmmActivityHstVO);
    }
    public List<CmmActivityHstVO> selectLocalToonOpenPageHotList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException{
    	return (List<CmmActivityHstVO>)localToonDAO.selectLocalToonOpenPageHotList(cmmActivityHstVO);
    }
    @Override
    public CmmAmsAssetMediaVO selectLocalToonDetail(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (CmmAmsAssetMediaVO)localToonDAO.selectLocalToonDetail(param);
    }
    @Override
    public int selectLocalToonDetailListTotCnt(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (Integer)localToonDAO.selectLocalToonDetailListTotCnt(param);
    }

    public List<DataMap> selectLocalToonDetailList(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (List<DataMap>)localToonDAO.selectLocalToonDetailList(param);
    }
    public List<CmmActivityHstVO> selectLocalToonOpenPageDetailList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException{
    	return (List<CmmActivityHstVO>)localToonDAO.selectLocalToonOpenPageDetailList(cmmActivityHstVO);
    }
    public List<DataMap> selectLocalToonDetailListAll(CmmAmsAssetMediaVO param) throws EgovBizException {
    	return (List<DataMap>)localToonDAO.selectLocalToonDetailListAll(param);
    }

}
