package kccf.ton.service;

import java.util.List;

import cmm.service.CmmActivityHstVO;
import cmm.service.CmmAmsAssetMediaVO;
import cmm.util.DataMap;
import egovframework.rte.fdl.cmmn.exception.EgovBizException;

public interface LocalToonService {
	List<CmmAmsAssetMediaVO> selectLocalToonTopList(CmmAmsAssetMediaVO param) throws EgovBizException;
	int selectLocalToonListTotCnt(CmmAmsAssetMediaVO param) throws EgovBizException;
	List<CmmAmsAssetMediaVO> selectLocalToonList(CmmAmsAssetMediaVO param) throws EgovBizException;
	List<CmmActivityHstVO> selectLocalToonOpenPageList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException;
	List<CmmActivityHstVO> selectLocalToonOpenPageHotList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException;
	CmmAmsAssetMediaVO selectLocalToonDetail(CmmAmsAssetMediaVO param) throws EgovBizException;
	int selectLocalToonDetailListTotCnt(CmmAmsAssetMediaVO param) throws EgovBizException;
	List<DataMap> selectLocalToonDetailList(CmmAmsAssetMediaVO param) throws EgovBizException;
	List<CmmActivityHstVO> selectLocalToonOpenPageDetailList(CmmActivityHstVO cmmActivityHstVO) throws EgovBizException;
	List<DataMap> selectLocalToonDetailListAll(CmmAmsAssetMediaVO param) throws EgovBizException;
}
